package ObserverPattern;

import java.util.List;
/**
 * this is the implementation of the subject. 
 * @author cliu3
 *
 */
public class CommentaryObject implements Subject{

	private final List<Observer>observers; // the observer list. 
	private String updates;// basic description of the updated information
	private final String subjectDescription; // basics of the subject
	
	// constructor.
	public CommentaryObject(List<Observer>observers,String subjectDetails){
		this.observers = observers;
		this.subjectDescription = subjectDetails;
	}
	
	// add observer
	@Override
	public void subscribeObserver(Observer observer) {
		observers.add(observer);
	}

	// remove observer
	@Override
	public void unSubscribeObserver(Observer observer) {
		int index = observers.indexOf(observer);
		observers.remove(index);
		
	}

	// notify all observers
	@Override
	public void notifyObservers() {
		//System.out.println();
		for(Observer observer : observers){
			observer.update(updates);
		}
		
	}

	/**
	 * set the updated information, it simulates updates of the subject, 
	 * automatically invoked the notifyObservers() to updata all observers. 
	 * @param desc
	 */
	@Override
	public void setUpdates(String updates) {
		this.updates = updates;
		notifyObservers();
	}

}
